package CPAN::Test::Dummy::Perl5::cpm::Module1;
use strict;
use warnings;

our $VERSION = '0.001';

1;
__END__

=encoding utf-8

=head1 NAME

CPAN::Test::Dummy::Perl5::cpm::Module1 - a dummy module

=head1 SYNOPSIS

  use CPAN::Test::Dummy::Perl5::cpm::Module1;

=head1 DESCRIPTION

CPAN::Test::Dummy::Perl5::cpm::Module1 is a dummy module
created to demonstrate issues that can occur during CPAN module installation.

=head1 COPYRIGHT AND LICENSE

Copyright 2025 Shoichi Kaji <skaji@cpan.org>

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
